@@ -499,6 +499,65 @@ def parse_args(argv: Optional[List[str]] = None) -> argparse.Namespace:
         help="Maintain the image's original aspect ratio.",
         action="store_true",
     )
+
+    # Rotate.
+    rotate_subparser = subparsers.add_parser(
+        "rotate",
+        parents=[global_parser],
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        help="Reorient an image.",
+        description=(
+            "To rotate an image, use the angle and fill arguments listed\n"
+            "below."
+            "\n\n"
+            "   ---"
+            "\n\n"
+            "By default, this program does the following:\n"
+            "    - places output in the current working directory\n"
+            "    - does not modify filenames\n"
+            "    - skips file conflicts"
+            "\n\n"
+            "The above defaults can be changed, however, by using optional\n"
+            "arguments listed below."
+        ),
+    )
+    rotate_group = rotate_subparser.add_argument_group(
+        "optional rotate arguments",
+    )
+    rotate_group.add_argument(
+        "-A",
+        "--angle",
+        help="The number of degrees counter clockwise by which to rotate.",
+        type=int,
+        metavar="NUMBER",
+    )
+    rotate_group.add_argument(
+        "--fill",
+        help="Fill open areas with black pixels.",
+        action="store_true",
+    )
+
+    # Transpose.
+    subparsers.add_parser(
+        "transpose",
+        parents=[global_parser],
+        formatter_class=argparse.RawDescriptionHelpFormatter,
+        help="Flip an image horizontally.",
+        description=(
+            "Any images included as input will be transposed. No additional\n"
+            "arguments are required."
+            "\n\n"
+            "   ---"
+            "\n\n"
+            "By default, this program does the following:\n"
+            "    - places output in the current working directory\n"
+            "    - does not modify filenames\n"
+            "    - skips file conflicts"
+            "\n\n"
+            "The above defaults can be changed, however, by using optional\n"
+            "arguments listed below."
+        ),
+    )
     return primary_parser.parse_args(argv)
 
 
