@@ -253,6 +253,50 @@ def resize_image(
     return resized_image
 
 
+def rotate_image(image: Image, angle: int, fill: bool) -> Image:
+    """Rotate an image.
+
+    Parameters
+    ----------
+    image : :obj:`PIL.Image`
+        The image to be resized.
+    angle : int
+        The number of degrees to rotate the image counter clockwise
+    fill : bool
+        Whether or not to fill open areas with black pixels.
+
+    Returns
+    -------
+    :obj:`PIL.Image`
+        The rotated image.
+
+    """
+    if angle is not None and fill:
+        mod_im = image.rotate(angle, expand=True, fillcolor="#000000")
+    elif angle is not None:
+        mod_im = image.rotate(angle, expand=True)
+    else:
+        mod_im = image
+    return mod_im
+
+
+def transpose_image(image: Image) -> Image:
+    """Flip an image horizontally.
+
+    Parameters
+    ----------
+    image : :obj:`PIL.Image`
+        The image to be transposed.
+
+    Returns
+    -------
+    :obj:`PIL.Image`
+        The transposed image.
+
+    """
+    return image.transpose(0)
+
+
 def save_image(
     im: Image,
     path: Path,
